@@ -1,6 +1,6 @@
 package Mercury;
 # ABSTRACT: Main broker application class
-$Mercury::VERSION = '0.005';
+$Mercury::VERSION = '0.006';
 
 use Mojo::Base 'Mojolicious';
 use Scalar::Util qw( refaddr );
@@ -14,8 +14,9 @@ my %pushpull;
 
 
 sub add_bus_peer {
-    my ( $c, $topic ) = @_;
-    $bus_topics{ $topic }{ refaddr $c } = $c;
+    my ( $c, $topic, %options ) = @_;
+    $options{_controller} = $c;
+    $bus_topics{ $topic }{ refaddr $c } = \%options;
     return;
 }
 
@@ -30,8 +31,10 @@ sub remove_bus_peer {
 sub send_bus_message {
     my ( $self, $topic, $message ) = @_;
     my $self_id = refaddr $self;
-    for my $id ( grep { $_ ne $self_id } keys %{ $bus_topics{ $topic } } ) {
-        $bus_topics{ $topic }{ $id }->send( $message );
+    for my $id ( keys %{ $bus_topics{ $topic } } ) {
+        my $peer = $bus_topics{ $topic }{ $id };
+        next unless $id ne $self_id || $peer->{echo};
+        $peer->{_controller}->send( $message );
     }
     return;
 }
@@ -67,7 +70,8 @@ sub route_websocket_bus {
     Mojo::IOLoop->stream($c->tx->connection)->timeout(1200);
 
     my $topic = $c->stash( 'topic' );
-    $c->add_bus_peer( $topic );
+    my $echo = $c->param('echo');
+    $c->add_bus_peer( $topic, echo => $echo );
 
     $c->on( message => sub {
         my ( $c, $msg ) = @_;
@@ -184,7 +188,7 @@ Mercury - Main broker application class
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
@@ -208,6 +212,12 @@ published on the topic.
 This is a shorter way of doing both C</pub/*topic> and C</sub/*topic>,
 without the hierarchal message passing.
 
+One difference is that by default a sender will not receive a message
+that they sent. To enable this behavior, pass a true value as the C<echo>
+query parameter when establishing the websocket.
+
+  $ua->websocket('/bus/foo?echo=1' => sub { ... });
+
 =head2 /sub/*topic
 
 Establish a WebSocket to subscribe to the given C<topic>. Messages published
